@@ -8,7 +8,7 @@ _file = Path(__xonsh__.env.get('XDG_CACHE_HOME', '~/.cache')).expanduser() / 'xo
 
 @events.on_post_init
 def on_post_init(**_):
-    if __xonsh__.env["PWD"] == __xonsh__.env["HOME"] and _file.exists():
+    if Path(__xonsh__.env["PWD"]) == Path(__xonsh__.env["HOME"]).resolve() and _file.exists():
         __xonsh__.subproc_captured_stdout(['cd', _file.read_text()])
 
 @events.on_chdir
